from setuptools import setup


setup(
    name='salom',
    packages=['salom'],
    description='Salom!!',
    version='0.0.1',
    url='https://turgunov.uz/',
    author='Shukrullo Turgunov',
    author_email='shookrullo@gmail.com',
    keywords=['pip', 'pypi']
)